%
% Harmonic method for physical properties - seismic velocities
%
% Example of 3D plot with vector radius of P-wave velocity
%
% additional vectors : 
% propagation (black), polarizations S1 (blue) and S2 (red)
%
% Ralf Hielscher and David Mainprice 30/11/2018
% 
%% clear workspace and close all plots
clear all
close all
%**************************************************************************
%% Seismic velocities and anisotropy - single crystal plots
%
% b-axis to EAST convention of International Union of Crystallography standards 
plotb2east
%
% Choose fontsize before  calling this function.
setMTEXpref('FontSize',20);
%
%************************************************
% Define elastic stiffness tensor (GPa)
%************************************************
%
% Reference Elastic constants
% Stishovite Weidner et al 1982 JGR
%
% Reference Crystal Structure
% Sinclair and Ringwood 78 Nature P422 d=4.2901
%
% Define density (g/cm3)
 rho= 4.2901;
% elastic Cij stiffness tensor (GPa) as matrix M
 M =.... 
 [[  453.00  211.00  203.00    0.00    0.00    0.00];...
 [   211.00  453.00  203.00    0.00    0.00    0.00];...
 [   203.00  203.00  776.00    0.00    0.00    0.00];...
 [     0.00    0.00    0.00  252.00    0.00    0.00];...
 [     0.00    0.00    0.00    0.00  252.00    0.00];...
 [     0.00    0.00    0.00    0.00    0.00  302.00]];
% Define Cartesian Tensor crystal crystalSymmetry & frame
cs_Tensor = crystalSymmetry('4/mmm',[  4.9133  4.9133  5.4048],...
 [  90.0000  90.0000  90.0000]*degree,'x||a','z||c',...
 'mineral','Stishovite 1982');
% Define elastic stiffness tensor Cijkl with MTEX tensor command
C = stiffnessTensor(M,cs_Tensor,'density',rho);
%**************************************************************************
%% 3d surface with radius vector with Vp values
% figure;plotEmptySphere
% 'FaceColor', 'k','EdgeColor','w'
%**************************************************************************
[vp,vs1,vs2,pp,ps1,ps2] = C.velocity('harmonic');
close all
surf(vp)
hold on
% propagation vectors
prop = S2AxisFieldHarmonic.normal;
quiver3(vp,prop,'color', 'k','LineWidth',3,'arrowSize',1.3,'maxHeadSize',1.5,'DisplayName','Vp')
% S1-wave polarization vectors
quiver3(vp,ps1,'color','m','LineWidth',3,'arrowSize',1.0,'maxHeadSize',1.5)
% S2-wave polarization vectors
quiver3(vp,ps2,'color','c','LineWidth',3,'arrowSize',1.0,'maxHeadSize',1.5)
hold off
mtexColorbar('Title','Vp (km/s)','fontsize',20,'Location','south') 
% Red = slow to Blue = fast in Seismology
colormap(red2blueColorMap)
legend('vp','prop','ps1','ps2','Location','west')
mtexTitle('Stishovite : P-wave velocity 3D surface (km/s)','FontSize',30)