%
%**************************************************************************
% Inner core seismic anisotropy
%**************************************************************************
%
% Reference
% Yunguo Li, Lidunka Vocadlo, John P. Brodholt (2018)
% The elastic properties of hcp-Fe alloys under the conditions of the Earth?s inner core
% Earth and Planetary Science Letters 493,118?127.
%
% Script by David Mainprice 10/07/2018
%
% The calculated elastic tensor of the ternary hcp-Fe60Si2C2SQS structure
% Fe60Si2C2 AIMD rho=13.119 Bs=1481 G=177 Vs=3.67 Vp=11.44
%      SS Model  rho=13.098 Bs=1472 G=184 Vs=3.74 Vp=11.45
% at 6500K following the triclinic symmetry is:
% density
rho = 13.098;
% import Voigt matrix with 'broken' hexagonal symmetry
M =.... 
 [[  1640 1344 1055 -40   2  10 ];...
 [   1344 1618 1079  16 -52 -44 ];...
 [   1055 1079 1811  71  53  16 ];...
 [   -41    16   71  174  35  61];...
 [     2   -52   53   35  117 31];...
 [    10   -44   16   61  31  79]];
% Define Cartesian Tensor crystal crystalSymmetry & frame
% use triclinic symmetry
cs_Tensor = crystalSymmetry('-1',[8.4499 8.4418 6.7673],...
 [  90.0000  90.0000  90.0000]*degree,'x||a','z||c',...
 'mineral','Fe60Si2C2 AIMD 2018');
% Define elastic stiffness tensor Cijkl with MTEX load tensor command
C = stiffnessTensor(M,cs_Tensor,'density',rho)
%**************************************************************************
% Impose hexgonal symmetry using rotations about the c-axis of tensor C
% For an aggregate it would TVI=Transverse Isotropic with vertical axis Z
%**************************************************************************
% rotation angles 0 to 360 interval 0.1 degree
angles = linspace(0,360,3610);
% all rotations 0 to 360
r = rotation('axis',vector3d(0,0,1),'angle',angles*degree);
% all rotated Mij
M_rotated = rotate(C,r);
% average of C_rotated TVI = Hexagonal
TVI = sum(M_rotated)./length(angles)
fprintf(' \n');
fprintf(' Hexagonal or VTI symmetry Cij Elastic tensor (GPa) \n')
fprintf(' \n')
% convert tensor to matrix form
MM = TVI.Voigt;
for i=1:6
  fprintf('%8.2f %8.2f %8.2f %8.2f %8.2f %8.2f \n',MM(i,:))
end
% check hexagonal of model above C66 = (C11-C12)/2 = 110.7603
C66_TVI_Hex = (MM(1,1)-MM(1,2))/2;
fprintf(' Hexagonal Test (C11-C12)/2=C66 must be exact\n')
fprintf('%s  %8.2f\n',' Test (C11-C12)/2=',C66_TVI_Hex)
% Moakher and Norris(2006) Method
MN =.... 
 [[  1578 1396 1067   0   0   0 ];...
 [   1396 1578 1067   0   0   0 ];...
 [   1067 1067 1811   0   0   0 ];...
 [     0    0    0   146   0  0 ];...
 [     0    0    0    0  146  0 ];...
 [     0    0    0    0   0  182]];
fprintf(' \n');
fprintf(' Moakher and Norris(2006) Method Cij Elastic tensor (GPa) \n')
fprintf(' \n')
for i=1:6
  fprintf('%8.2f %8.2f %8.2f %8.2f %8.2f %8.2f \n',MN(i,:))
end
C66_Moakher_Norris = (MN(1,1)-MN(1,2))/2;
fprintf(' Hexagonal Test (C11-C12)/2=C66 must be exact\n')
fprintf('%s  %8.2f\n',' Test (C11-C12)/2=',C66_Moakher_Norris)
%**************************************************************************
% Define corrected hexagonal symmetry
%**************************************************************************
cs_Tensor = crystalSymmetry('6/mmm',[ 8.4499 8.4418 6.7673],...
 [  90.0000  90.0000  120.00]*degree,'x||a*','z||c',...
 'mineral','Fe60Si2C2 AIMD 2018');
% Define elastic stiffness tensor Cijkl with MTEX load tensor command
% using my way of converting triclinic to hexagonal
C = stiffnessTensor(MM,cs_Tensor,'density',rho)
%**************************************************************************
%% plot single crystal inner core
%**************************************************************************
% plot x to east
%plotx2east
% plot b to east
plotb2east
% You can change these labels to fit your application
Label_X='X1'; Label_Y='X2';Label_Z='X3';
%
% 'upper'; or 'lower'
hemisphere ='upper';
%
% symm = 1 one max min marker
% symm = 2 for generating symmetrise max and min values on the plot 
% 
symm = 1;% one max min marker
%
% plot font_size = set your fontsize  25,20,15  etc
font_size=20;
%
Multi_seismic_plot_MTEX5(C,Label_X,Label_Y,Label_Z,hemisphere,symm,font_size)
%
% file name
saveFigure('Inner_Core_Seismic_Properties.pdf')